@@ -26,7 +26,6 @@
 #include <utility>
 #include <vector>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/random/bit_gen_ref.h"
 #include "absl/status/status.h"
@@ -42,8 +41,11 @@
 #include "src/core/lib/event_engine/channel_args_endpoint_config.h"
 #include "src/core/lib/event_engine/event_engine_context.h"
 #include "src/core/lib/event_engine/extensions/chaotic_good_extension.h"
+#include "src/core/lib/event_engine/extensions/supports_fd.h"
+#include "src/core/lib/event_engine/posix.h"
 #include "src/core/lib/event_engine/query_extensions.h"
 #include "src/core/lib/event_engine/resolved_address_internal.h"
+#include "src/core/lib/event_engine/shim.h"
 #include "src/core/lib/event_engine/tcp_socket_utils.h"
 #include "src/core/lib/event_engine/utils.h"
 #include "src/core/lib/iomgr/error.h"
@@ -64,6 +66,8 @@
 #include "src/core/lib/transport/error_utils.h"
 #include "src/core/lib/transport/promise_endpoint.h"
 #include "src/core/server/server.h"
+#include "src/core/telemetry/metrics.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/orphanable.h"
 #include "src/core/util/ref_counted_ptr.h"
 #include "src/core/util/status_helper.h"
@@ -75,6 +79,30 @@ namespace chaotic_good {
 
 namespace {
 const Duration kConnectionDeadline = Duration::Seconds(120);
+
+void LogInitFailure(Server* server, std::string what,
+                    std::optional<absl::Status> status) {
+  LOG(ERROR) << "ChaoticGoodServerListener Init failed: " << what
+             << " with status: "
+             << (status.has_value() ? status->ToString() : "no status");
+  auto* server_node = server->channelz_node();
+  if (server_node != nullptr) {
+    if (status.has_value()) {
+      server_node->NewTraceNode(std::move(what), ": ", *status).Commit();
+    } else {
+      server_node->NewTraceNode(std::move(what)).Commit();
+    }
+  }
+}
+
+void LogInformational(Server* server, std::string what) {
+  VLOG(2) << "ChaoticGoodServerListener: " << what;
+  auto* server_node = server->channelz_node();
+  if (server_node != nullptr) {
+    server_node->NewTraceNode(std::move(what)).Commit();
+  }
+}
+
 }  // namespace
 
 using grpc_event_engine::experimental::EventEngine;
@@ -101,6 +129,80 @@ ChaoticGoodServerListener::~ChaoticGoodServerListener() {
   }
 }
 
+absl::StatusOr<
+    std::unique_ptr<grpc_event_engine::experimental::EventEngine::Listener>>
+ChaoticGoodServerListener::CreateListener(bool must_be_posix) {
+  GRPC_CHECK_NE(event_engine_, nullptr);
+  auto* event_engine_supports_fd =
+      grpc_event_engine::experimental::QueryExtension<
+          grpc_event_engine::experimental::EventEngineSupportsFdExtension>(
+          event_engine_.get());
+  if (must_be_posix && event_engine_supports_fd == nullptr) {
+    LogInitFailure(server_,
+                   "EventEngine does not support external fd listeners",
+                   absl::InternalError(
+                       "EventEngine does not support external fd listeners"));
+    return absl::InternalError(
+        "EventEngine does not support external fd listeners");
+  }
+  auto shutdown_cb =
+      [self = RefAsSubclass<ChaoticGoodServerListener>()](absl::Status status) {
+        if (!status.ok()) {
+          self->LogConnectionFailure("Server accept connection failed", status);
+        }
+      };
+  if (event_engine_supports_fd != nullptr) {
+    grpc_event_engine::experimental::PosixEventEngineWithFdSupport::
+        PosixAcceptCallback accept_cb =
+            [self = RefAsSubclass<ChaoticGoodServerListener>()](
+                int listener_fd, std::unique_ptr<EventEngine::Endpoint> ep,
+                bool is_external, MemoryAllocator,
+                grpc_event_engine::experimental::SliceBuffer* pending_data) {
+              ExecCtx exec_ctx;
+              LogInformational(
+                  self->server_,
+                  absl::StrCat("Accepting connection: ",
+                               ResolvedAddressToString(ep->GetPeerAddress())
+                                   .value_or("<<unknown peer address>>")));
+              grpc_byte_buffer* pending_buf = nullptr;
+              if (pending_data != nullptr && pending_data->Length() > 0) {
+                pending_buf = grpc_raw_byte_buffer_create(nullptr, 0);
+                grpc_slice_buffer_swap(&pending_buf->data.raw.slice_buffer,
+                                       pending_data->c_slice_buffer());
+              }
+              MutexLock lock(&self->mu_);
+              if (self->shutdown_) return;
+              self->connection_list_.emplace(MakeOrphanable<ActiveConnection>(
+                  self, std::move(ep), is_external, listener_fd, pending_buf));
+            };
+    return event_engine_supports_fd->CreatePosixListener(
+        std::move(accept_cb), std::move(shutdown_cb),
+        grpc_event_engine::experimental::ChannelArgsEndpointConfig(args_),
+        std::make_unique<MemoryQuota>(
+            MakeRefCounted<channelz::ResourceQuotaNode>(
+                "chaotic_good_server_listener")));
+  }
+  EventEngine::Listener::AcceptCallback accept_cb =
+      [self = RefAsSubclass<ChaoticGoodServerListener>()](
+          std::unique_ptr<EventEngine::Endpoint> ep, MemoryAllocator) {
+        ExecCtx exec_ctx;
+        LogInformational(
+            self->server_,
+            absl::StrCat("Accepting connection: ",
+                         ResolvedAddressToString(ep->GetPeerAddress())
+                             .value_or("<<unknown peer address>>")));
+        MutexLock lock(&self->mu_);
+        if (self->shutdown_) return;
+        self->connection_list_.emplace(MakeOrphanable<ActiveConnection>(
+            self, std::move(ep), false, 0, nullptr));
+      };
+  return event_engine_->CreateListener(
+      std::move(accept_cb), std::move(shutdown_cb),
+      grpc_event_engine::experimental::ChannelArgsEndpointConfig(args_),
+      std::make_unique<MemoryQuota>(MakeRefCounted<channelz::ResourceQuotaNode>(
+          "chaotic_good_server_listener")));
+}
+
 absl::StatusOr<int> ChaoticGoodServerListener::Bind(
     grpc_event_engine::experimental::EventEngine::ResolvedAddress addr) {
   if (GRPC_TRACE_FLAG_ENABLED(chaotic_good)) {
@@ -108,27 +210,9 @@ absl::StatusOr<int> ChaoticGoodServerListener::Bind(
     LOG(INFO) << "CHAOTIC_GOOD: Listen on "
               << (str.ok() ? str->c_str() : str.status().ToString());
   }
-  EventEngine::Listener::AcceptCallback accept_cb =
-      [self = RefAsSubclass<ChaoticGoodServerListener>()](
-          std::unique_ptr<EventEngine::Endpoint> ep, MemoryAllocator) {
-        ExecCtx exec_ctx;
-        MutexLock lock(&self->mu_);
-        if (self->shutdown_) return;
-        self->connection_list_.emplace(
-            MakeOrphanable<ActiveConnection>(self, std::move(ep)));
-      };
-  auto shutdown_cb = [](absl::Status status) {
-    if (!status.ok()) {
-      LOG(ERROR) << "Server accept connection failed: " << status;
-    }
-  };
-  CHECK_NE(event_engine_, nullptr);
-  auto ee_listener = event_engine_->CreateListener(
-      std::move(accept_cb), std::move(shutdown_cb),
-      grpc_event_engine::experimental::ChannelArgsEndpointConfig(args_),
-      std::make_unique<MemoryQuota>("chaotic_good_server_listener"));
+  auto ee_listener = CreateListener(/*must_be_posix=*/false);
   if (!ee_listener.ok()) {
-    LOG(ERROR) << "Bind failed: " << ee_listener.status().ToString();
+    LogInitFailure(server_, "Bind failed", ee_listener.status());
     return ee_listener.status();
   }
   ee_listener_ = std::move(ee_listener.value());
@@ -139,11 +223,63 @@ absl::StatusOr<int> ChaoticGoodServerListener::Bind(
   return port_num;
 }
 
+absl::Status ChaoticGoodServerListener::BindExternal(std::string addr,
+                                                     const ChannelArgs& args) {
+  using grpc_event_engine::experimental::EventEngine;
+  class FdHandler final : public TcpServerFdHandler {
+   public:
+    FdHandler(RefCountedPtr<ChaoticGoodServerListener> listener,
+              grpc_event_engine::experimental::ListenerSupportsFdExtension*
+                  listener_supports_fd)
+        : listener_(std::move(listener)),
+          listener_supports_fd_(listener_supports_fd) {}
+
+    void Handle(int listener_fd, int fd,
+                grpc_byte_buffer* pending_read) override {
+      grpc_event_engine::experimental::SliceBuffer pending_data;
+      if (pending_read != nullptr) {
+        pending_data =
+            grpc_event_engine::experimental::SliceBuffer::TakeCSliceBuffer(
+                pending_read->data.raw.slice_buffer);
+      }
+      GRPC_CHECK(
+          GRPC_LOG_IF_ERROR("listener_handle_external_connection",
+                            listener_supports_fd_->HandleExternalConnection(
+                                listener_fd, fd, &pending_data)));
+    }
+
+   private:
+    RefCountedPtr<ChaoticGoodServerListener> listener_;
+    grpc_event_engine::experimental::ListenerSupportsFdExtension*
+        listener_supports_fd_;
+  };
+  auto listener = CreateListener(/*must_be_posix=*/true);
+  if (!listener.ok()) {
+    LogInitFailure(server_, "BindExternal failed", listener.status());
+    return listener.status();
+  }
+  auto* listener_supports_fd = grpc_event_engine::experimental::QueryExtension<
+      grpc_event_engine::experimental::ListenerSupportsFdExtension>(
+      listener->get());
+  if (listener_supports_fd == nullptr) {
+    LogInitFailure(server_,
+                   "EventEngine does not support external fd listeners",
+                   listener.status());
+    return absl::InternalError(
+        "EventEngine does not support external fd listeners");
+  }
+  ee_listener_ = std::move(*listener);
+  TcpServerFdHandler** arg_val = args.GetPointer<TcpServerFdHandler*>(addr);
+  *arg_val = new FdHandler(RefAsSubclass<ChaoticGoodServerListener>(),
+                           listener_supports_fd);
+  return absl::OkStatus();
+}
+
 absl::Status ChaoticGoodServerListener::StartListening() {
-  CHECK(ee_listener_ != nullptr);
+  GRPC_CHECK(ee_listener_ != nullptr);
   auto status = ee_listener_->Start();
   if (!status.ok()) {
-    LOG(ERROR) << "Start listening failed: " << status;
+    LogInitFailure(server_, "Start listening failed", status);
   } else {
     GRPC_TRACE_LOG(chaotic_good, INFO) << "CHAOTIC_GOOD: Started listening";
   }
@@ -152,8 +288,10 @@ absl::Status ChaoticGoodServerListener::StartListening() {
 
 ChaoticGoodServerListener::ActiveConnection::ActiveConnection(
     RefCountedPtr<ChaoticGoodServerListener> listener,
-    std::unique_ptr<EventEngine::Endpoint> endpoint)
-    : listener_(std::move(listener)) {
+    std::unique_ptr<EventEngine::Endpoint> endpoint, bool is_external,
+    int listener_fd, grpc_byte_buffer* pending_data)
+    : listener_(std::move(listener)),
+      acceptor_{nullptr, 0, 0, is_external, listener_fd, pending_data} {
   arena_->SetContext<grpc_event_engine::experimental::EventEngine>(
       listener_->event_engine_.get());
   handshaking_state_ = MakeRefCounted<HandshakingState>(Ref());
@@ -162,6 +300,9 @@ ChaoticGoodServerListener::ActiveConnection::ActiveConnection(
 
 ChaoticGoodServerListener::ActiveConnection::~ActiveConnection() {
   if (receive_settings_activity_ != nullptr) receive_settings_activity_.reset();
+  if (acceptor_.pending_data != nullptr) {
+    grpc_byte_buffer_destroy(acceptor_.pending_data);
+  }
 }
 
 void ChaoticGoodServerListener::ActiveConnection::Orphan() {
@@ -245,7 +386,7 @@ void ChaoticGoodServerListener::DataConnectionListener::Orphaned() {
   absl::flat_hash_map<std::string, PendingConnectionInfo> pending_connections;
   {
     MutexLock lock(&mu_);
-    CHECK(!shutdown_);
+    GRPC_CHECK(!shutdown_);
     pending_connections = std::move(pending_connections_);
     pending_connections_.clear();
     shutdown_ = true;
@@ -275,13 +416,18 @@ ChaoticGoodServerListener::ActiveConnection::HandshakingState::HandshakingState(
 
 void ChaoticGoodServerListener::ActiveConnection::HandshakingState::Start(
     std::unique_ptr<EventEngine::Endpoint> endpoint) {
+  CoreConfiguration::Get().handshaker_registry().AddHandshakers(
+      HANDSHAKER_SERVER, connection_->args(), nullptr, handshake_mgr_.get());
+  RefCountedPtr<channelz::BaseNode> base_node =
+      connection_->listener_->server_->channelz_node()->Ref();
   handshake_mgr_->DoHandshake(
       OrphanablePtr<grpc_endpoint>(
           grpc_event_engine_endpoint_create(std::move(endpoint))),
-      connection_->args(),
+      connection_->args().SetObject(std::move(base_node)),
       Timestamp::Now() + connection_->listener_->data_connection_listener_
                              ->connection_timeout(),
-      nullptr, [self = Ref()](absl::StatusOr<HandshakerArgs*> result) {
+      &connection_->acceptor_,
+      [self = Ref()](absl::StatusOr<HandshakerArgs*> result) {
         self->OnHandshakeDone(std::move(result));
       });
 }
@@ -298,7 +444,7 @@ auto ChaoticGoodServerListener::ActiveConnection::HandshakingState::
         if (frame_header.ok()) {
           if (frame_header->header.type != FrameType::kSettings) {
             frame_header = absl::InternalError("Not a settings frame");
-          } else if (frame_header->payload_connection_id != 0) {
+          } else if (frame_header->payload_tag != 0) {
             frame_header = absl::InternalError("Unexpected connection id");
           } else if (frame_header->header.stream_id != 0) {
             frame_header = absl::InternalError("Unexpected stream id");
@@ -371,19 +517,25 @@ auto ChaoticGoodServerListener::ActiveConnection::HandshakingState::
       write_buffer.AddTiny(TcpFrameHeader::kFrameHeaderSize));
   frame.SerializePayload(write_buffer);
   return TrySeq(
-      self->connection_->endpoint_.Write(std::move(write_buffer)), [self]() {
+      self->connection_->endpoint_.Write(std::move(write_buffer),
+                                         PromiseEndpoint::WriteArgs{}),
+      [self]() {
         auto config =
             std::move(std::get<ControlConnection>(self->data_).config);
+        auto& ep = self->connection_->endpoint_;
+        auto socket_node =
+            TcpFrameTransport::MakeSocketNode(self->connection_->args(), ep);
         auto frame_transport = MakeOrphanable<TcpFrameTransport>(
-            config.MakeTcpFrameTransportOptions(),
-            std::move(self->connection_->endpoint_),
+            config.MakeTcpFrameTransportOptions(), std::move(ep),
             config.TakePendingDataEndpoints(),
-            self->connection_->args().GetObjectRef<EventEngine>());
+            MakeRefCounted<TransportContext>(
+                self->connection_->handshake_result_args(),
+                std::move(socket_node)));
         return self->connection_->listener_->server_->SetupTransport(
-            new ChaoticGoodServerTransport(self->connection_->args(),
-                                           std::move(frame_transport),
-                                           config.MakeMessageChunker()),
-            nullptr, self->connection_->args(), nullptr);
+            new ChaoticGoodServerTransport(
+                self->connection_->handshake_result_args(),
+                std::move(frame_transport), config.MakeMessageChunker()),
+            nullptr, self->connection_->handshake_result_args());
       });
 }
 
@@ -397,7 +549,8 @@ auto ChaoticGoodServerListener::ActiveConnection::HandshakingState::
       write_buffer.AddTiny(TcpFrameHeader::kFrameHeaderSize));
   frame.SerializePayload(write_buffer);
   // ignore encoding errors: they will be logged separately already
-  return TrySeq(self->connection_->endpoint_.Write(std::move(write_buffer)),
+  return TrySeq(self->connection_->endpoint_.Write(
+                    std::move(write_buffer), PromiseEndpoint::WriteArgs{}),
                 [self]() mutable {
                   self->connection_->listener_->data_connection_listener_
                       ->FinishDataConnection(
@@ -419,18 +572,19 @@ auto ChaoticGoodServerListener::ActiveConnection::HandshakingState::
 void ChaoticGoodServerListener::ActiveConnection::HandshakingState::
     OnHandshakeDone(absl::StatusOr<HandshakerArgs*> result) {
   if (!result.ok()) {
-    LOG_EVERY_N_SEC(ERROR, 5) << "Handshake failed: " << result.status();
+    connection_->listener_->LogConnectionFailure("Handshake failed",
+                                                 result.status());
     connection_->Done();
     return;
   }
-  CHECK_NE(*result, nullptr);
+  GRPC_CHECK_NE(*result, nullptr);
   if ((*result)->endpoint == nullptr) {
-    LOG_EVERY_N_SEC(ERROR, 5)
-        << "Server handshake done but has empty endpoint.";
+    connection_->listener_->LogConnectionFailure(
+        "Server handshake done but has empty endpoint", std::nullopt);
     connection_->Done();
     return;
   }
-  CHECK(grpc_event_engine::experimental::grpc_is_event_engine_endpoint(
+  GRPC_CHECK(grpc_event_engine::experimental::grpc_is_event_engine_endpoint(
       (*result)->endpoint.get()));
   auto ee_endpoint =
       grpc_event_engine::experimental::grpc_take_wrapped_event_engine_endpoint(
@@ -439,6 +593,7 @@ void ChaoticGoodServerListener::ActiveConnection::HandshakingState::
       grpc_event_engine::experimental::ChaoticGoodExtension>(ee_endpoint.get());
   connection_->endpoint_ =
       PromiseEndpoint(std::move(ee_endpoint), SliceBuffer());
+  connection_->handshake_result_args_ = (*result)->args;
   auto activity = MakeActivity(
       [self = Ref(), chaotic_good_ext]() {
         return TrySeq(
@@ -463,8 +618,8 @@ void ChaoticGoodServerListener::ActiveConnection::HandshakingState::
       EventEngineWakeupScheduler(connection_->listener_->event_engine_),
       [self = Ref()](absl::Status status) {
         if (!status.ok()) {
-          GRPC_TRACE_LOG(chaotic_good, ERROR)
-              << "Server setting frame handling failed: " << status;
+          self->connection_->listener_->LogConnectionFailure(
+              "Chaotic Good handshake failed", status);
         }
         self->connection_->Done();
       },
@@ -487,45 +642,51 @@ void ChaoticGoodServerListener::Orphan() {
   Unref();
 };
 
-}  // namespace chaotic_good
-}  // namespace grpc_core
-
-int grpc_server_add_chaotic_good_port(grpc_server* server, const char* addr) {
-  if (!grpc_core::IsChaoticGoodFramingLayerEnabled()) {
-    return grpc_server_add_chaotic_good_legacy_port(server, addr);
+absl::StatusOr<int> AddChaoticGoodPort(Server* server, std::string addr,
+                                       const ChannelArgs& args) {
+  if (!IsChaoticGoodFramingLayerEnabled()) {
+    return chaotic_good_legacy::AddLegacyChaoticGoodPort(server, addr, args);
+  }
+  if (absl::StartsWith(addr, "external:")) {
+    auto listener =
+        MakeOrphanable<chaotic_good::ChaoticGoodServerListener>(server, args);
+    if (auto status = listener->BindExternal(addr, args); !status.ok()) {
+      return status;
+    }
+    server->AddListener(std::move(listener));
+    return -1;
   }
   using grpc_event_engine::experimental::EventEngine;
-  grpc_core::ExecCtx exec_ctx;
-  auto* const core_server = grpc_core::Server::FromC(server);
-  const std::string parsed_addr = grpc_core::URI::PercentDecode(addr);
+  const std::string parsed_addr = URI::PercentDecode(addr);
   absl::StatusOr<std::vector<EventEngine::ResolvedAddress>> results =
       std::vector<EventEngine::ResolvedAddress>();
-  if (grpc_core::IsEventEngineDnsNonClientChannelEnabled()) {
+  if (IsEventEngineDnsNonClientChannelEnabled() &&
+      !grpc_event_engine::experimental::
+          EventEngineExperimentDisabledForPython()) {
     absl::StatusOr<std::unique_ptr<EventEngine::DNSResolver>> ee_resolver =
-        core_server->channel_args().GetObjectRef<EventEngine>()->GetDNSResolver(
+        args.GetObjectRef<EventEngine>()->GetDNSResolver(
             EventEngine::DNSResolver::ResolverOptions());
     if (!ee_resolver.ok()) {
-      LOG(ERROR) << "Failed to resolve " << addr << ": "
-                 << ee_resolver.status().ToString();
-      return 0;
+      LogInitFailure(server, absl::StrCat("Failed to resolve ", addr),
+                     ee_resolver.status());
+      return ee_resolver.status();
     }
     results = grpc_event_engine::experimental::LookupHostnameBlocking(
         ee_resolver->get(), parsed_addr, absl::StrCat(0xd20));
     if (!results.ok()) {
-      LOG(ERROR) << "Failed to resolve " << addr << ": "
-                 << results.status().ToString();
-      return 0;
+      LogInitFailure(server, absl::StrCat("Failed to resolve ", addr),
+                     results.status());
+      return results.status();
     }
   } else {
     // TODO(yijiem): Remove this after event_engine_dns_non_client_channel
     // is fully enabled.
-    const auto resolved_or =
-        grpc_core::GetDNSResolver()->LookupHostnameBlocking(
-            parsed_addr, absl::StrCat(0xd20));
+    const auto resolved_or = GetDNSResolver()->LookupHostnameBlocking(
+        parsed_addr, absl::StrCat(0xd20));
     if (!resolved_or.ok()) {
-      LOG(ERROR) << "Failed to resolve " << addr << ": "
-                 << resolved_or.status().ToString();
-      return 0;
+      LogInitFailure(server, absl::StrCat("Failed to resolve ", addr),
+                     resolved_or.status());
+      return resolved_or.status();
     }
     for (const auto& addr : *resolved_or) {
       results->push_back(
@@ -535,14 +696,15 @@ int grpc_server_add_chaotic_good_port(grpc_server* server, const char* addr) {
   int port_num = 0;
   std::vector<std::pair<std::string, absl::Status>> error_list;
   for (const auto& ee_addr : results.value()) {
-    auto listener = grpc_core::MakeOrphanable<
-        grpc_core::chaotic_good::ChaoticGoodServerListener>(
-        grpc_core::Server::FromC(server), core_server->channel_args());
+    auto listener =
+        MakeOrphanable<chaotic_good::ChaoticGoodServerListener>(server, args);
     std::string addr_str =
         *grpc_event_engine::experimental::ResolvedAddressToString(ee_addr);
     GRPC_TRACE_LOG(chaotic_good, INFO) << "BIND: " << addr_str;
     auto bind_result = listener->Bind(ee_addr);
     if (!bind_result.ok()) {
+      LogInitFailure(server, absl::StrCat("Failed to bind ", addr_str),
+                     bind_result.status());
       error_list.push_back(
           std::pair(std::move(addr_str), bind_result.status()));
       continue;
@@ -550,11 +712,14 @@ int grpc_server_add_chaotic_good_port(grpc_server* server, const char* addr) {
     if (port_num == 0) {
       port_num = bind_result.value();
     } else {
-      CHECK(port_num == bind_result.value());
+      GRPC_CHECK(port_num == bind_result.value());
     }
-    core_server->AddListener(std::move(listener));
+    server->AddListener(std::move(listener));
   }
   if (error_list.size() == results->size()) {
+    LogInitFailure(server,
+                   absl::StrCat("Failed to bind any address for ", addr),
+                   std::nullopt);
     LOG(ERROR) << "Failed to bind any address for " << addr;
     for (const auto& error : error_list) {
       LOG(ERROR) << "  " << error.first << ": " << error.second;
@@ -568,3 +733,6 @@ int grpc_server_add_chaotic_good_port(grpc_server* server, const char* addr) {
   }
   return port_num;
 }
+
+}  // namespace chaotic_good
+}  // namespace grpc_core
