@@ -29,12 +29,12 @@
 #include <memory>
 #include <utility>
 
-#include "absl/log/check.h"
 #include "absl/status/status.h"
 #include "src/core/lib/event_engine/default_event_engine.h"
 #include "src/core/lib/iomgr/error.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
 #include "src/core/lib/surface/completion_queue.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/time.h"
 
 namespace grpc {
@@ -64,10 +64,10 @@ class AlarmImpl : public grpc::internal::CompletionQueueTag {
     GRPC_CQ_INTERNAL_REF(cq->cq(), "alarm");
     cq_ = cq->cq();
     tag_ = tag;
-    CHECK(grpc_cq_begin_op(cq_, this));
+    GRPC_CHECK(grpc_cq_begin_op(cq_, this));
     Ref();
-    CHECK(cq_armed_.exchange(true) == false);
-    CHECK(!callback_armed_.load());
+    GRPC_CHECK(cq_armed_.exchange(true) == false);
+    GRPC_CHECK(!callback_armed_.load());
     cq_timer_handle_ = event_engine_->RunAfter(
         grpc_core::Timestamp::FromTimespecRoundUp(deadline) -
             grpc_core::ExecCtx::Get()->Now(),
@@ -78,8 +78,8 @@ class AlarmImpl : public grpc::internal::CompletionQueueTag {
     // Don't use any CQ at all. Instead just use the timer to fire the function
     callback_ = std::move(f);
     Ref();
-    CHECK(callback_armed_.exchange(true) == false);
-    CHECK(!cq_armed_.load());
+    GRPC_CHECK(callback_armed_.exchange(true) == false);
+    GRPC_CHECK(!cq_armed_.load());
     callback_timer_handle_ = event_engine_->RunAfter(
         grpc_core::Timestamp::FromTimespecRoundUp(deadline) -
             grpc_core::ExecCtx::Get()->Now(),
@@ -104,7 +104,6 @@ class AlarmImpl : public grpc::internal::CompletionQueueTag {
  private:
   void OnCQAlarm(grpc_error_handle error) {
     cq_armed_.store(false);
-    grpc_core::ApplicationCallbackExecCtx callback_exec_ctx;
     grpc_core::ExecCtx exec_ctx;
     // Preserve the cq and reset the cq_ so that the alarm
     // can be reset when the alarm tag is delivered.
@@ -119,7 +118,6 @@ class AlarmImpl : public grpc::internal::CompletionQueueTag {
 
   void OnCallbackAlarm(bool is_ok) {
     callback_armed_.store(false);
-    grpc_core::ApplicationCallbackExecCtx callback_exec_ctx;
     grpc_core::ExecCtx exec_ctx;
     callback_(is_ok);
     Unref();
