@@ -37,14 +37,13 @@
 #include <string>
 #include <vector>
 
-#include "absl/log/check.h"
 #include "absl/memory/memory.h"
 #include "absl/strings/string_view.h"
 #include "gtest/gtest.h"
+#include "src/core/config/core_configuration.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/channel/channel_stack.h"
 #include "src/core/lib/channel/channel_stack_builder_impl.h"
-#include "src/core/lib/config/core_configuration.h"
 #include "src/core/lib/experiments/experiments.h"
 #include "src/core/lib/iomgr/endpoint.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
@@ -52,6 +51,7 @@
 #include "src/core/lib/surface/channel_init.h"
 #include "src/core/lib/surface/channel_stack_type.h"
 #include "src/core/lib/transport/transport.h"
+#include "src/core/util/grpc_check.h"
 #include "test/core/test_util/test_config.h"
 
 namespace {
@@ -73,6 +73,10 @@ class FakeTransport final : public grpc_core::Transport {
   void SetPollsetSet(grpc_stream*, grpc_pollset_set*) override {}
   void PerformOp(grpc_transport_op*) override {}
   void Orphan() override {}
+  grpc_core::RefCountedPtr<grpc_core::channelz::SocketNode> GetSocketNode()
+      const override {
+    return nullptr;
+  }
 
  private:
   absl::string_view transport_name_;
@@ -93,7 +97,7 @@ std::vector<std::string> MakeStack(const char* transport_name,
   builder.SetTarget("foo.test.google.fr");
   {
     grpc_core::ExecCtx exec_ctx;
-    CHECK(grpc_core::CoreConfiguration::Get().channel_init().CreateStack(
+    GRPC_CHECK(grpc_core::CoreConfiguration::Get().channel_init().CreateStack(
         &builder));
   }
 
@@ -143,19 +147,38 @@ TEST(ChannelStackFilters, LooksAsExpected) {
             std::vector<std::string>(
                 {"server", "message_size", "server_call_tracer", "connected"}));
 
-  EXPECT_EQ(
-      MakeStack("chttp2", no_args, GRPC_CLIENT_DIRECT_CHANNEL),
-      std::vector<std::string>({"authority", "message_size", "http-client",
-                                "compression", "connected"}));
-  EXPECT_EQ(
-      MakeStack("chttp2", no_args, GRPC_CLIENT_SUBCHANNEL),
-      std::vector<std::string>({"authority", "message_size", "http-client",
-                                "compression", "connected"}));
-
-  EXPECT_EQ(MakeStack("chttp2", no_args, GRPC_SERVER_CHANNEL),
-            std::vector<std::string>({"server", "message_size", "http-server",
-                                      "compression", "server_call_tracer",
-                                      "connected"}));
+#ifndef GRPC_NO_FILTER_FUSION
+  if (grpc_core::IsFuseFiltersEnabled()) {
+    EXPECT_EQ(MakeStack("chttp2", no_args, GRPC_CLIENT_DIRECT_CHANNEL),
+              std::vector<std::string>({"authority",
+                                        "message_size+http-client+compression",
+                                        "connected"}));
+    EXPECT_EQ(MakeStack("chttp2", no_args, GRPC_CLIENT_SUBCHANNEL),
+              std::vector<std::string>({"authority",
+                                        "message_size+http-client+compression",
+                                        "connected"}));
+    EXPECT_EQ(MakeStack("chttp2", no_args, GRPC_SERVER_CHANNEL),
+              std::vector<std::string>(
+                  {"server",
+                   "message_size+http-server+compression+server_call_tracer",
+                   "connected"}));
+  } else {
+#endif
+    EXPECT_EQ(
+        MakeStack("chttp2", no_args, GRPC_CLIENT_DIRECT_CHANNEL),
+        std::vector<std::string>({"authority", "message_size", "http-client",
+                                  "compression", "connected"}));
+    EXPECT_EQ(
+        MakeStack("chttp2", no_args, GRPC_CLIENT_SUBCHANNEL),
+        std::vector<std::string>({"authority", "message_size", "http-client",
+                                  "compression", "connected"}));
+    EXPECT_EQ(MakeStack("chttp2", no_args, GRPC_SERVER_CHANNEL),
+              std::vector<std::string>({"server", "message_size", "http-server",
+                                        "compression", "server_call_tracer",
+                                        "connected"}));
+#ifndef GRPC_NO_FILTER_FUSION
+  }
+#endif
   EXPECT_EQ(MakeStack(nullptr, no_args, GRPC_CLIENT_CHANNEL),
             std::vector<std::string>({"client_idle", "client-channel"}));
 }
