@@ -20,9 +20,9 @@
 
 #include <memory>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "gtest/gtest.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/time.h"
 #include "test/core/end2end/cq_verifier.h"
 #include "test/core/end2end/end2end_tests.h"
@@ -87,7 +87,7 @@ void ServerStreaming(CoreEnd2endTest& test, int num_messages) {
     EXPECT_EQ(server_message.payload(), "hello world");
     num_messages_received++;
   }
-  CHECK_EQ(num_messages_received, num_messages);
+  GRPC_CHECK_EQ(num_messages_received, num_messages);
   if (!seen_status) {
     test.Expect(1, true);
     test.Step();
@@ -96,13 +96,13 @@ void ServerStreaming(CoreEnd2endTest& test, int num_messages) {
   EXPECT_EQ(server_status.message(), "xyz");
 }
 
-CORE_END2END_TEST(Http2Test, ServerStreaming) { ServerStreaming(*this, 1); }
+CORE_END2END_TEST(Http2Tests, ServerStreaming) { ServerStreaming(*this, 1); }
 
-CORE_END2END_TEST(Http2Test, ServerStreamingEmptyStream) {
+CORE_END2END_TEST(Http2Tests, ServerStreamingEmptyStream) {
   ServerStreaming(*this, 0);
 }
 
-CORE_END2END_TEST(Http2Test, ServerStreaming10Messages) {
+CORE_END2END_TEST(Http2Tests, ServerStreaming10Messages) {
   // TODO(yashykt): Remove this once b/376283636 is fixed.
   ConfigVars::Overrides overrides;
   overrides.default_ssl_roots_file_path = CA_CERT_PATH;
