@@ -16,11 +16,7 @@
 //
 //
 
-#include "absl/time/time.h"
-#include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/iomgr/port.h"
-#include "src/core/util/notification.h"
-#include "src/core/util/time.h"
 
 // This test won't work except with posix sockets enabled
 #ifdef GRPC_POSIX_SOCKET_TCP
@@ -30,19 +26,21 @@
 #include <grpc/grpc.h>
 #include <grpc/support/alloc.h>
 #include <grpc/support/time.h>
-#include <gtest/gtest.h>
 #include <limits.h>
 #include <string.h>
 #include <sys/socket.h>
 #include <sys/types.h>
 #include <unistd.h>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
+#include "absl/time/time.h"
+#include "gtest/gtest.h"
+#include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/event_engine/channel_args_endpoint_config.h"
 #include "src/core/lib/event_engine/default_event_engine.h"
 #include "src/core/lib/event_engine/posix.h"
 #include "src/core/lib/event_engine/shim.h"
+#include "src/core/lib/experiments/experiments.h"
 #include "src/core/lib/iomgr/buffer_list.h"
 #include "src/core/lib/iomgr/ev_posix.h"
 #include "src/core/lib/iomgr/event_engine_shims/endpoint.h"
@@ -51,6 +49,9 @@
 #include "src/core/lib/iomgr/tcp_posix.h"
 #include "src/core/lib/slice/slice_internal.h"
 #include "src/core/util/crash.h"
+#include "src/core/util/grpc_check.h"
+#include "src/core/util/notification.h"
+#include "src/core/util/time.h"
 #include "src/core/util/useful.h"
 #include "test/core/iomgr/endpoint_tests.h"
 #include "test/core/test_util/test_config.h"
@@ -78,11 +79,11 @@ static constexpr int64_t kDeadlineMillis = 20000;
 
 static void create_sockets(int sv[2]) {
   int flags;
-  CHECK_EQ(socketpair(AF_UNIX, SOCK_STREAM, 0, sv), 0);
+  GRPC_CHECK_EQ(socketpair(AF_UNIX, SOCK_STREAM, 0, sv), 0);
   flags = fcntl(sv[0], F_GETFL, 0);
-  CHECK_EQ(fcntl(sv[0], F_SETFL, flags | O_NONBLOCK), 0);
+  GRPC_CHECK_EQ(fcntl(sv[0], F_SETFL, flags | O_NONBLOCK), 0);
   flags = fcntl(sv[1], F_GETFL, 0);
-  CHECK_EQ(fcntl(sv[1], F_SETFL, flags | O_NONBLOCK), 0);
+  GRPC_CHECK_EQ(fcntl(sv[1], F_SETFL, flags | O_NONBLOCK), 0);
 }
 
 static ssize_t fill_socket(int fd) {
@@ -99,7 +100,7 @@ static ssize_t fill_socket(int fd) {
       total_bytes += write_bytes;
     }
   } while (write_bytes >= 0 || errno == EINTR);
-  CHECK(errno == EAGAIN);
+  GRPC_CHECK(errno == EAGAIN);
   return total_bytes;
 }
 
@@ -141,7 +142,7 @@ static size_t count_slices(grpc_slice* slices, size_t nslices,
   for (i = 0; i < nslices; ++i) {
     buf = GRPC_SLICE_START_PTR(slices[i]);
     for (j = 0; j < GRPC_SLICE_LENGTH(slices[i]); ++j) {
-      CHECK(buf[j] == *current_data);
+      GRPC_CHECK(buf[j] == *current_data);
       *current_data = (*current_data + 1) % 256;
     }
     num_bytes += GRPC_SLICE_LENGTH(slices[i]);
@@ -155,14 +156,14 @@ static void read_cb(void* user_data, grpc_error_handle error) {
   size_t read_bytes;
   int current_data;
 
-  CHECK_OK(error);
+  GRPC_CHECK_OK(error);
 
   gpr_mu_lock(g_mu);
   current_data = state->read_bytes % 256;
   // The number of bytes read each time this callback is invoked must be >=
   // the min_progress_size.
   if (grpc_core::IsTcpFrameSizeTuningEnabled()) {
-    CHECK(state->min_progress_size <= state->incoming.length);
+    GRPC_CHECK(state->min_progress_size <= state->incoming.length);
   }
   read_bytes = count_slices(state->incoming.slices, state->incoming.count,
                             &current_data);
@@ -170,7 +171,8 @@ static void read_cb(void* user_data, grpc_error_handle error) {
   LOG(INFO) << "Read " << read_bytes << " bytes of "
             << state->target_read_bytes;
   if (state->read_bytes >= state->target_read_bytes) {
-    CHECK(GRPC_LOG_IF_ERROR("kick", grpc_pollset_kick(g_pollset, nullptr)));
+    GRPC_CHECK(
+        GRPC_LOG_IF_ERROR("kick", grpc_pollset_kick(g_pollset, nullptr)));
     gpr_mu_unlock(g_mu);
   } else {
     gpr_mu_unlock(g_mu);
@@ -207,9 +209,8 @@ static void read_test(size_t num_bytes, size_t slice_size,
   grpc_channel_args args = {GPR_ARRAY_SIZE(a), a};
   ep = grpc_tcp_create(
       grpc_fd_create(sv[1], "read_test", false),
-      TcpOptionsFromEndpointConfig(
-          grpc_event_engine::experimental::ChannelArgsEndpointConfig(
-              grpc_core::ChannelArgs::FromC(&args))),
+      grpc_event_engine::experimental::ChannelArgsEndpointConfig(
+          grpc_core::ChannelArgs::FromC(&args)),
       "test");
   grpc_endpoint_add_to_pollset(ep, g_pollset);
 
@@ -230,13 +231,13 @@ static void read_test(size_t num_bytes, size_t slice_size,
   gpr_mu_lock(g_mu);
   while (state.read_bytes < state.target_read_bytes) {
     grpc_pollset_worker* worker = nullptr;
-    CHECK(GRPC_LOG_IF_ERROR("pollset_work",
-                            grpc_pollset_work(g_pollset, &worker, deadline)));
+    GRPC_CHECK(GRPC_LOG_IF_ERROR(
+        "pollset_work", grpc_pollset_work(g_pollset, &worker, deadline)));
     gpr_mu_unlock(g_mu);
     grpc_core::ExecCtx::Get()->Flush();
     gpr_mu_lock(g_mu);
   }
-  CHECK(state.read_bytes == state.target_read_bytes);
+  GRPC_CHECK(state.read_bytes == state.target_read_bytes);
   gpr_mu_unlock(g_mu);
 
   grpc_slice_buffer_destroy(&state.incoming);
@@ -271,9 +272,8 @@ static void large_read_test(size_t slice_size, int min_progress_size) {
   grpc_channel_args args = {GPR_ARRAY_SIZE(a), a};
   ep = grpc_tcp_create(
       grpc_fd_create(sv[1], "large_read_test", false),
-      TcpOptionsFromEndpointConfig(
-          grpc_event_engine::experimental::ChannelArgsEndpointConfig(
-              grpc_core::ChannelArgs::FromC(&args))),
+      grpc_event_engine::experimental::ChannelArgsEndpointConfig(
+          grpc_core::ChannelArgs::FromC(&args)),
       "test");
   grpc_endpoint_add_to_pollset(ep, g_pollset);
 
@@ -294,13 +294,13 @@ static void large_read_test(size_t slice_size, int min_progress_size) {
   gpr_mu_lock(g_mu);
   while (state.read_bytes < state.target_read_bytes) {
     grpc_pollset_worker* worker = nullptr;
-    CHECK(GRPC_LOG_IF_ERROR("pollset_work",
-                            grpc_pollset_work(g_pollset, &worker, deadline)));
+    GRPC_CHECK(GRPC_LOG_IF_ERROR(
+        "pollset_work", grpc_pollset_work(g_pollset, &worker, deadline)));
     gpr_mu_unlock(g_mu);
     grpc_core::ExecCtx::Get()->Flush();
     gpr_mu_lock(g_mu);
   }
-  CHECK(state.read_bytes == state.target_read_bytes);
+  GRPC_CHECK(state.read_bytes == state.target_read_bytes);
   gpr_mu_unlock(g_mu);
 
   grpc_slice_buffer_destroy(&state.incoming);
@@ -316,7 +316,8 @@ struct write_socket_state {
 
 static grpc_slice* allocate_blocks(size_t num_bytes, size_t slice_size,
                                    size_t* num_blocks, uint8_t* current_data) {
-  size_t nslices = num_bytes / slice_size + (num_bytes % slice_size ? 1u : 0u);
+  size_t nslices =
+      (num_bytes / slice_size) + (num_bytes % slice_size ? 1u : 0u);
   grpc_slice* slices =
       static_cast<grpc_slice*>(gpr_malloc(sizeof(grpc_slice) * nslices));
   size_t num_bytes_left = num_bytes;
@@ -334,18 +335,18 @@ static grpc_slice* allocate_blocks(size_t num_bytes, size_t slice_size,
       (*current_data)++;
     }
   }
-  CHECK_EQ(num_bytes_left, 0);
+  GRPC_CHECK_EQ(num_bytes_left, 0);
   return slices;
 }
 
 static void write_done(void* user_data /* write_socket_state */,
                        grpc_error_handle error) {
-  CHECK_OK(error);
+  GRPC_CHECK_OK(error);
   struct write_socket_state* state =
       static_cast<struct write_socket_state*>(user_data);
   gpr_mu_lock(g_mu);
   state->write_done = 1;
-  CHECK(
+  GRPC_CHECK(
       GRPC_LOG_IF_ERROR("pollset_kick", grpc_pollset_kick(g_pollset, nullptr)));
   gpr_mu_unlock(g_mu);
 }
@@ -360,12 +361,12 @@ void drain_socket_blocking(int fd, size_t num_bytes, size_t read_size) {
   grpc_core::ExecCtx exec_ctx;
 
   flags = fcntl(fd, F_GETFL, 0);
-  CHECK_EQ(fcntl(fd, F_SETFL, flags & ~O_NONBLOCK), 0);
+  GRPC_CHECK_EQ(fcntl(fd, F_SETFL, flags & ~O_NONBLOCK), 0);
 
   for (;;) {
     grpc_pollset_worker* worker = nullptr;
     gpr_mu_lock(g_mu);
-    CHECK(GRPC_LOG_IF_ERROR(
+    GRPC_CHECK(GRPC_LOG_IF_ERROR(
         "pollset_work",
         grpc_pollset_work(g_pollset, &worker,
                           grpc_core::Timestamp::FromTimespecRoundUp(
@@ -376,16 +377,16 @@ void drain_socket_blocking(int fd, size_t num_bytes, size_t read_size) {
       bytes_read =
           read(fd, buf, bytes_left > read_size ? read_size : bytes_left);
     } while (bytes_read < 0 && errno == EINTR);
-    CHECK_GE(bytes_read, 0);
+    GRPC_CHECK_GE(bytes_read, 0);
     for (i = 0; i < bytes_read; ++i) {
-      CHECK(buf[i] == current);
+      GRPC_CHECK(buf[i] == current);
       current = (current + 1) % 256;
     }
     bytes_left -= static_cast<size_t>(bytes_read);
     if (bytes_left == 0) break;
   }
   flags = fcntl(fd, F_GETFL, 0);
-  CHECK_EQ(fcntl(fd, F_SETFL, flags | O_NONBLOCK), 0);
+  GRPC_CHECK_EQ(fcntl(fd, F_SETFL, flags | O_NONBLOCK), 0);
 
   gpr_free(buf);
 }
@@ -423,9 +424,8 @@ static void write_test(size_t num_bytes, size_t slice_size) {
   grpc_channel_args args = {GPR_ARRAY_SIZE(a), a};
   ep = grpc_tcp_create(
       grpc_fd_create(sv[1], "write_test", false),
-      TcpOptionsFromEndpointConfig(
-          grpc_event_engine::experimental::ChannelArgsEndpointConfig(
-              grpc_core::ChannelArgs::FromC(&args))),
+      grpc_event_engine::experimental::ChannelArgsEndpointConfig(
+          grpc_core::ChannelArgs::FromC(&args)),
       "test");
   grpc_endpoint_add_to_pollset(ep, g_pollset);
 
@@ -439,8 +439,10 @@ static void write_test(size_t num_bytes, size_t slice_size) {
   GRPC_CLOSURE_INIT(&write_done_closure, write_done, &state,
                     grpc_schedule_on_exec_ctx);
 
-  grpc_endpoint_write(ep, &outgoing, &write_done_closure, nullptr,
-                      /*max_frame_size=*/INT_MAX);
+  grpc_event_engine::experimental::EventEngine::Endpoint::WriteArgs write_args;
+  write_args.set_max_frame_size(INT_MAX);
+  grpc_endpoint_write(ep, &outgoing, &write_done_closure,
+                      std::move(write_args));
   drain_socket_blocking(sv[0], num_bytes, num_bytes);
   exec_ctx.Flush();
   gpr_mu_lock(g_mu);
@@ -449,8 +451,8 @@ static void write_test(size_t num_bytes, size_t slice_size) {
     if (state.write_done) {
       break;
     }
-    CHECK(GRPC_LOG_IF_ERROR("pollset_work",
-                            grpc_pollset_work(g_pollset, &worker, deadline)));
+    GRPC_CHECK(GRPC_LOG_IF_ERROR(
+        "pollset_work", grpc_pollset_work(g_pollset, &worker, deadline)));
     gpr_mu_unlock(g_mu);
     exec_ctx.Flush();
     gpr_mu_lock(g_mu);
@@ -504,7 +506,8 @@ static void release_fd_test(size_t num_bytes, size_t slice_size) {
   a[1].type = GRPC_ARG_POINTER;
   a[1].value.pointer.p = grpc_resource_quota_create("test");
   a[1].value.pointer.vtable = grpc_resource_quota_arg_vtable();
-  auto memory_quota = std::make_unique<grpc_core::MemoryQuota>("bar");
+  auto memory_quota = std::make_unique<grpc_core::MemoryQuota>(
+      grpc_core::MakeRefCounted<grpc_core::channelz::ResourceQuotaNode>("bar"));
   grpc_channel_args args = {GPR_ARRAY_SIZE(a), a};
   if (grpc_event_engine::experimental::UseEventEngineListener()) {
     // Create an event engine wrapped endpoint to test release_fd operations.
@@ -522,12 +525,11 @@ static void release_fd_test(size_t num_bytes, size_t slice_size) {
   } else {
     ep = grpc_tcp_create(
         grpc_fd_create(sv[1], "read_test", false),
-        TcpOptionsFromEndpointConfig(
-            grpc_event_engine::experimental::ChannelArgsEndpointConfig(
-                grpc_core::ChannelArgs::FromC(&args))),
+        grpc_event_engine::experimental::ChannelArgsEndpointConfig(
+            grpc_core::ChannelArgs::FromC(&args)),
         "test");
-    CHECK(grpc_tcp_fd(ep) == sv[1]);
-    CHECK_GE(sv[1], 0);
+    GRPC_CHECK(grpc_tcp_fd(ep) == sv[1]);
+    GRPC_CHECK_GE(sv[1], 0);
   }
   grpc_endpoint_add_to_pollset(ep, g_pollset);
 
@@ -547,23 +549,23 @@ static void release_fd_test(size_t num_bytes, size_t slice_size) {
   gpr_mu_lock(g_mu);
   while (state.read_bytes < state.target_read_bytes) {
     grpc_pollset_worker* worker = nullptr;
-    CHECK(GRPC_LOG_IF_ERROR("pollset_work",
-                            grpc_pollset_work(g_pollset, &worker, deadline)));
+    GRPC_CHECK(GRPC_LOG_IF_ERROR(
+        "pollset_work", grpc_pollset_work(g_pollset, &worker, deadline)));
     VLOG(2) << "wakeup: read=" << state.read_bytes
             << " target=" << state.target_read_bytes;
     gpr_mu_unlock(g_mu);
     grpc_core::ExecCtx::Get()->Flush();
     gpr_mu_lock(g_mu);
   }
-  CHECK(state.read_bytes == state.target_read_bytes);
+  GRPC_CHECK(state.read_bytes == state.target_read_bytes);
   gpr_mu_unlock(g_mu);
 
   grpc_slice_buffer_destroy(&state.incoming);
   grpc_tcp_destroy_and_release_fd(ep, &fd, &fd_released_cb);
   grpc_core::ExecCtx::Get()->Flush();
   rel_fd.notify.WaitForNotificationWithTimeout(absl::Seconds(20));
-  CHECK_EQ(rel_fd.fd_released_done, 1);
-  CHECK(fd == sv[1]);
+  GRPC_CHECK_EQ(rel_fd.fd_released_done, 1);
+  GRPC_CHECK(fd == sv[1]);
   written_bytes = fill_socket_partial(sv[0], num_bytes);
   drain_socket_blocking(fd, written_bytes, written_bytes);
   written_bytes = fill_socket_partial(fd, num_bytes);
@@ -616,15 +618,13 @@ static grpc_endpoint_test_fixture create_fixture_tcp_socketpair(
   grpc_channel_args args = {GPR_ARRAY_SIZE(a), a};
   f.client_ep = grpc_tcp_create(
       grpc_fd_create(sv[0], "fixture:client", false),
-      TcpOptionsFromEndpointConfig(
-          grpc_event_engine::experimental::ChannelArgsEndpointConfig(
-              grpc_core::ChannelArgs::FromC(&args))),
+      grpc_event_engine::experimental::ChannelArgsEndpointConfig(
+          grpc_core::ChannelArgs::FromC(&args)),
       "test");
   f.server_ep = grpc_tcp_create(
       grpc_fd_create(sv[1], "fixture:server", false),
-      TcpOptionsFromEndpointConfig(
-          grpc_event_engine::experimental::ChannelArgsEndpointConfig(
-              grpc_core::ChannelArgs::FromC(&args))),
+      grpc_event_engine::experimental::ChannelArgsEndpointConfig(
+          grpc_core::ChannelArgs::FromC(&args)),
       "test");
   grpc_endpoint_add_to_pollset(f.client_ep, g_pollset);
   grpc_endpoint_add_to_pollset(f.server_ep, g_pollset);
@@ -647,6 +647,15 @@ int main(int argc, char** argv) {
   ::testing::InitGoogleTest(&argc, argv);
   grpc::testing::TestEnvironment env(&argc, argv);
   grpc_init();
+  if (grpc_core::IsEventEngineForAllOtherEndpointsEnabled() &&
+      !grpc_event_engine::experimental::
+          EventEngineExperimentDisabledForPython()) {
+    LOG(INFO) << "This test is skipped since the "
+                 "event_engine_for_all_other_endpoints experiment is enabled, "
+                 "which replaces iomgr grpc_fds with minimal implementations. "
+                 "The test uses grpc_fds directly, which will not work.";
+    return 0;
+  }
   {
     grpc_core::ExecCtx exec_ctx;
     g_pollset = static_cast<grpc_pollset*>(gpr_zalloc(grpc_pollset_size()));
