@@ -944,7 +944,6 @@ TEST_F(TlsConfigTest, MinimumValidConfig) {
 }
 
 TEST_F(TlsConfigTest, SystemRootCerts) {
-  ScopedExperimentalEnvVar env_var("GRPC_EXPERIMENTAL_XDS_SYSTEM_ROOT_CERTS");
   Cluster cluster;
   cluster.set_name("foo");
   cluster.set_type(cluster.EDS);
@@ -2016,8 +2015,6 @@ TEST_F(MetadataTest, UntypedMetadata) {
 // they're being passed through.  A complete set of tests for metadata
 // validation is in xds_metadata_test.cc.
 TEST_F(MetadataTest, MetadataUnparseable) {
-  ScopedExperimentalEnvVar env_var(
-      "GRPC_EXPERIMENTAL_XDS_GCP_AUTHENTICATION_FILTER");
   Cluster cluster;
   cluster.set_type(cluster.EDS);
   cluster.mutable_eds_cluster_config()->mutable_eds_config()->mutable_self();
