@@ -26,7 +26,6 @@
 #include <thread>
 #include <vector>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/memory/memory.h"
 #include "absl/strings/str_cat.h"
@@ -39,6 +38,7 @@
 #include "src/core/ext/filters/http/server/http_server_filter.h"
 #include "src/core/server/server.h"
 #include "src/core/util/env.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/tmpfile.h"
 #include "src/core/xds/grpc/xds_client_grpc.h"
 #include "src/core/xds/xds_client/xds_channel_args.h"
@@ -155,7 +155,7 @@ XdsEnd2endTest::ServerThread::ServerThread(
 
 void XdsEnd2endTest::ServerThread::Start() {
   LOG(INFO) << "starting " << Type() << " server on port " << port_;
-  CHECK(!running_);
+  GRPC_CHECK(!running_);
   running_ = true;
   StartAllServices();
   grpc_core::Mutex mu;
@@ -377,6 +377,13 @@ const char XdsEnd2endTest::kServerCertPath[] =
 const char XdsEnd2endTest::kServerKeyPath[] =
     "src/core/tsi/test_creds/server1.key";
 
+const char XdsEnd2endTest::kSpiffeCaCertPath[] =
+    "test/core/tsi/test_creds/spiffe_end2end/ca.pem";
+const char XdsEnd2endTest::kSpiffeServerCertPath[] =
+    "test/core/tsi/test_creds/spiffe_end2end/server_spiffe.pem";
+const char XdsEnd2endTest::kSpiffeServerKeyPath[] =
+    "test/core/tsi/test_creds/spiffe_end2end/server.key";
+
 const char XdsEnd2endTest::kRequestMessage[] = "Live long and prosper.";
 
 XdsEnd2endTest::XdsEnd2endTest(
@@ -727,22 +734,26 @@ size_t XdsEnd2endTest::SendRpcsAndCountFailuresWithMessage(
 
 void XdsEnd2endTest::LongRunningRpc::StartRpc(
     grpc::testing::EchoTestService::Stub* stub, const RpcOptions& rpc_options) {
-  sender_thread_ = std::thread([this, stub, rpc_options]() {
-    EchoRequest request;
-    EchoResponse response;
-    rpc_options.SetupRpc(&context_, &request);
-    status_ = stub->Echo(&context_, request, &response);
+  LOG(INFO) << "Starting long-running RPC...";
+  rpc_options.SetupRpc(&context_, &request_);
+  stub->async()->Echo(&context_, &request_, &response_, [this](Status status) {
+    grpc_core::MutexLock lock(&mu_);
+    status_ = std::move(status);
+    cv_.Signal();
   });
 }
 
 void XdsEnd2endTest::LongRunningRpc::CancelRpc() {
   context_.TryCancel();
-  if (sender_thread_.joinable()) sender_thread_.join();
+  (void)GetStatus();
 }
 
 Status XdsEnd2endTest::LongRunningRpc::GetStatus() {
-  if (sender_thread_.joinable()) sender_thread_.join();
-  return status_;
+  grpc_core::MutexLock lock(&mu_);
+  while (!status_.has_value()) {
+    cv_.Wait(&mu_);
+  }
+  return *status_;
 }
 
 std::vector<std::unique_ptr<XdsEnd2endTest::ConcurrentRpc>>
@@ -848,7 +859,11 @@ void XdsEnd2endTest::SetProtoDuration(
 }
 
 std::string XdsEnd2endTest::MakeConnectionFailureRegex(
-    absl::string_view prefix, bool has_resolution_note) {
+    absl::string_view prefix, absl::string_view resolution_note) {
+  std::string resolution_note_str;
+  if (!resolution_note.empty()) {
+    resolution_note_str = absl::StrCat(" \\(", resolution_note, "\\)");
+  }
   return absl::StrCat(
       prefix,
       "(UNKNOWN|UNAVAILABLE): "
@@ -858,9 +873,10 @@ std::string XdsEnd2endTest::MakeConnectionFailureRegex(
       "(Failed to connect to remote host: )?"
       "(Timeout occurred: )?"
       // Parenthetical wrappers
-      "((Secure read failed|"
-      "Handshake read failed|"
-      "Delayed close due to in-progress write) \\()?"
+      "( ?\\(*("
+      "Secure read failed|"
+      "Handshake (read|write) failed|"
+      "Delayed close due to in-progress write|"
       // Syscall
       "((connect|sendmsg|recvmsg|getsockopt\\(SO\\_ERROR\\)): ?)?"
       // strerror() output or other message
@@ -873,9 +889,9 @@ std::string XdsEnd2endTest::MakeConnectionFailureRegex(
       // errno value
       "( \\([0-9]+\\))?"
       // close paren from wrappers above
-      "\\)?",
-      // xDS node ID
-      has_resolution_note ? " \\(xDS node ID:xds_end2end_test\\)" : "");
+      ")\\)*)+",
+      // resolution note, if any
+      resolution_note_str);
 }
 
 std::string XdsEnd2endTest::MakeTlsHandshakeFailureRegex(
@@ -909,11 +925,25 @@ XdsEnd2endTest::MakeIdentityKeyCertPairForTlsCreds() {
   return {{std::move(private_key), std::move(identity_cert)}};
 }
 
+std::vector<experimental::IdentityKeyCertPair>
+XdsEnd2endTest::MakeIdentityKeyCertPairForSpiffeMtlsCreds() {
+  std::string identity_cert =
+      grpc_core::testing::GetFileContents(kSpiffeServerCertPath);
+  std::string private_key =
+      grpc_core::testing::GetFileContents(kSpiffeServerKeyPath);
+  return {{std::move(private_key), std::move(identity_cert)}};
+}
+
 std::shared_ptr<ChannelCredentials>
 XdsEnd2endTest::CreateXdsChannelCredentials() {
   return XdsCredentials(CreateTlsChannelCredentials());
 }
 
+std::shared_ptr<ChannelCredentials>
+XdsEnd2endTest::CreateSpiffeXdsChannelCredentials() {
+  return XdsCredentials(CreateSpiffeTlsChannelCredentials());
+}
+
 std::shared_ptr<ChannelCredentials>
 XdsEnd2endTest::CreateTlsChannelCredentials() {
   auto certificate_provider = std::make_shared<StaticDataCertificateProvider>(
@@ -931,6 +961,23 @@ XdsEnd2endTest::CreateTlsChannelCredentials() {
   return grpc::experimental::TlsCredentials(options);
 }
 
+std::shared_ptr<ChannelCredentials>
+XdsEnd2endTest::CreateSpiffeTlsChannelCredentials() {
+  auto certificate_provider = std::make_shared<StaticDataCertificateProvider>(
+      grpc_core::testing::GetFileContents(kSpiffeCaCertPath),
+      MakeIdentityKeyCertPairForSpiffeMtlsCreds());
+  grpc::experimental::TlsChannelCredentialsOptions options;
+  options.set_certificate_provider(std::move(certificate_provider));
+  options.watch_root_certs();
+  options.watch_identity_key_cert_pairs();
+  auto verifier =
+      ExternalCertificateVerifier::Create<SyncCertificateVerifier>(true);
+  options.set_certificate_verifier(std::move(verifier));
+  options.set_verify_server_certs(true);
+  options.set_check_call_host(false);
+  return grpc::experimental::TlsCredentials(options);
+}
+
 std::shared_ptr<ServerCredentials>
 XdsEnd2endTest::CreateFakeServerCredentials() {
   return std::make_shared<SecureServerCredentials>(
@@ -962,5 +1009,21 @@ XdsEnd2endTest::CreateTlsServerCredentials() {
   return grpc::experimental::TlsServerCredentials(options);
 }
 
+std::shared_ptr<ServerCredentials>
+XdsEnd2endTest::CreateMtlsSpiffeServerCredentials() {
+  std::string root_cert =
+      grpc_core::testing::GetFileContents(kSpiffeCaCertPath);
+  auto certificate_provider =
+      std::make_shared<grpc::experimental::StaticDataCertificateProvider>(
+          std::move(root_cert), MakeIdentityKeyCertPairForSpiffeMtlsCreds());
+  grpc::experimental::TlsServerCredentialsOptions options(
+      std::move(certificate_provider));
+  options.watch_root_certs();
+  options.watch_identity_key_cert_pairs();
+  options.set_cert_request_type(
+      GRPC_SSL_REQUEST_AND_REQUIRE_CLIENT_CERTIFICATE_AND_VERIFY);
+  return grpc::experimental::TlsServerCredentials(options);
+}
+
 }  // namespace testing
 }  // namespace grpc
