@@ -19,13 +19,12 @@
 #ifndef GRPC_TEST_CPP_MICROBENCHMARKS_CALLBACK_STREAMING_PING_PONG_H
 #define GRPC_TEST_CPP_MICROBENCHMARKS_CALLBACK_STREAMING_PING_PONG_H
 
-#include <sstream>
-
 #include <benchmark/benchmark.h>
 
-#include "absl/log/check.h"
-#include "absl/log/log.h"
+#include <sstream>
 
+#include "absl/log/log.h"
+#include "src/core/util/grpc_check.h"
 #include "src/proto/grpc/testing/echo.grpc.pb.h"
 #include "test/cpp/microbenchmarks/callback_test_service.h"
 #include "test/cpp/microbenchmarks/fullstack_context_mutators.h"
@@ -71,8 +70,8 @@ class BidiClient : public grpc::ClientBidiReactor<EchoRequest, EchoResponse> {
   }
 
   void OnDone(const Status& s) override {
-    CHECK(s.ok());
-    CHECK_EQ(writes_complete_, msgs_to_send_);
+    GRPC_CHECK(s.ok());
+    GRPC_CHECK_EQ(writes_complete_, msgs_to_send_);
     if (state_->KeepRunning()) {
       writes_complete_ = 0;
       StartNewRpc();
